<!--

// Verifies a Login

function verifyLogin (login, theName, rootOk, required)
{
    var errorString = "";

    // Some fields do not require that a value be entered
    if (login == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // Check for special cases
    if (!rootOk && login == "root")
    {
        errorString = theName + ': root is a special login and cannot be used.';
        alert(errorString);
        return false;
    }
    // looks for one or more alphanumeric chars, plus '-' and '_'
    else if (/^[a-zA-Z0-9\-\_]+$/.test(login))
    {
        return true;
    }
    else
    {
        errorString = theName + ': '+login+' contains invalid characters.\nValid characters are a-z, A-Z, 0-9, - and _.';
        alert (errorString);
        return false;
    }
}  // verifyLogin


// Verifies a local user Login

function verifyLocalLogin (login, theName, rootOk, required)
{
    // Some fields do not require that a value be entered
    if (login == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // Check for special cases
    if (!rootOk && login == "root")
    {
        alert(theName + ': root is a special login and cannot be used.');
        return false;
    }
    // looks for a letter followed by one or more alphanumeric chars, 
    // plus '-' and '_'
    else if (/^[a-zA-Z][a-zA-Z0-9\-\_]*$/.test(login))
    {
        return true;
    }
    else
    {
        alert(theName + ': invalid format\n(valid characters are a-z, A-Z, 0-9, - and _, and must start with a letter).');
        return false;
    }
}  // verifyLocalLogin


// Verifies alphanumeric field

function verifyAlphaNum (val, theName, required)
{
    // Some fields do not require that a value be entered
    if (val == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // looks for one or more alphanumeric chars
    if (/^[a-zA-Z0-9]+$/.test(val))
    {
        return true;
    }
    else
    {
        alert (theName + ': '+val+' contains invalid characters.\nValid characters are a-z, A-Z and 0-9.');
        return false;
    }
}  // verifyAlphaNum


// Verifies numeric field

function verifyNum (val, theName, required)
{
    // Some fields do not require that a value be entered
    if (val == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // looks for one or more numeric chars
    if (/^[0-9]+$/.test(val))
    {
        return true;
    }
    else
    {
        alert (theName + ': '+val+' contains invalid characters.\nValid characters are 0-9.');
        return false;
    }
}  // verifyNum


// Verifies a UID

function verifyUID (uid, theName) 
{
    errorString = "";

    if (uid == "")
    {
        alert (theName + ': required field.');
        return false;
    }
    return verifyNumRange(uid, 101, 4294967295, theName, true);
}  // verifyUID


// Verifies a port list, see regular expression below
// Does not validate that the numbers are within the port range (16, 32, 48...)
// The server side will ignore anything over the number of ports.

function verifyPort(port, theName)
{
    // ok for a port list to be blank
    if (port == "")
      return true;

    // looks for:
    // 1. a 1 or 2 digit number, 
    // 2. optionally followed by a '-' and another 1 or 2 digit number
    // 3. optionally followed zero or more times by
    //    a. a comma
    //    b. a 1 or 2 digit number
    //    c. optionally followed by a '-' and another 1 or 2 digit number
    // U, u, L and l are allowed for upper and lower pc card slot
    // handles spaces anywhere (' *')
    if (/^([0-9]{1,2}|([0-9]{1,2} *- *[0-9]{1,2})|[uUlL])( *, *([0-9]{1,2}|([0-9]{1,2} *- *[0-9]{1,2})|[uUlL]))*$/.test(port))
    {
        return true;
    }
    else
    {
        alert(theName + ': invalid port list.\nA port list is a comma-separated list of numbers or ranges.');
        return false;
    }
}  // verifyPort


// Verifies an outlet list, see regular expression below
// Does not validate that the numbers are within the outlet range (4, ...)
// The server side will ignore anything over the number of outlets.

function verifyOutlet(outlet, theName)
{
    // ok for an outlet list to be blank
    if (outlet == "")
      return true;

    // looks for:
    // 1. a 1 digit number, 
    // 2. optionally followed by a '-' and another 1 digit number
    // 3. optionally followed zero or more times by
    //    a. a comma
    //    b. a 1 digit number
    //    c. optionally followed by a '-' and another 1 digit number
    // handles spaces anywhere (' *')
    if (/^[1-4] *(- *[1-4])?( *, *[1-4] *(- *[1-4])?)*$/.test(outlet))
    {
        return true;
    }
    else
    {
        alert(theName + ': invalid outlet list.\nAn outlet list is a comma-separated list of numbers or ranges.');
        return false;
    }
}  // verifyOutlet


// Verifies an escape or break sequence

function verifySeq(seq, theName)
{
  return true;
} // verifySeq


// Verifies a number is within a range

function verifyNumRange (numValue, lowNum, hiNum, theName, required)
{
    var errorString = "";

    // Some fields do not require that a value be entered
    if (numValue == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // looks for one or more numbers with any number of leading/trailing spaces
    if (/^ *[0-9]+ *$/.test(numValue))
    {
        if (numValue < lowNum || numValue > hiNum)
        {
            errorString = theName + ' must be in the range ' + lowNum + '-' + hiNum + '.';
            alert(errorString);
            return false;
        }
        else
            return true;
    }
    else
    {
        errorString = theName + ": contains invalid characters.\nValid characters are 0-9.";
        alert(errorString);
        return false;
    }
} // verifyNumRange


// Verifies a NFS remote directory (ie, "host:/path")

function verifyNfsRemote(dir, theName)
{
    var errorString = "";

    if (dir == "")
        return true;
    
    // looks for:
    // 1. one or more [A-Za-z0-9-_.] characters (for both IP and name)
    // 2. followed by a ':'
    // 3. followed by '/' and one or more [A-Za-z0-9-_.] characters
    // 4. #3 can be repeated one or more times
    // 5. An optional trailing slash
    if (/^[a-zA-Z0-9\-\_\.]+:(\/[A-Za-z0-9\-\_\.]+)+\/?$/.test(dir))
    {
        return true;
    }
    else
    {
        errorString = theName + ': invalid NFS remote directory.\nFormat is [Name or IP Address]:[Directory Path]'; 
        alert(errorString);
        return false;
    }
} // verifyNfsRemote


// Verifies a path.  See regex below for expected pattern.
// may require a leading slash.

function verifyPath(path, theName, leadSlash, required)
{
    var errorString = "";

    // Some fields do not require that a value be entered
    if (path == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // looks for:
    // 1. '/' and one or more [A-Za-z0-9-_.] characters
    // 2. #1 can be repeated one or more times
    // 3. An optional trailing slash
    // leadSlash indicates that a leading slash is required
    if (leadSlash && (/^\/([\w\-\.]+\/)*([\w\-\.]+\/?)?$/.test(path)))
    {
        return true;
    }
    else if (!leadSlash && (/^\/?([\w\-\.]+\/)*([\w\-\.]+\/?)?$/.test(path)))
    {
        return true;
    }
    else
    {
        errorString = theName + ': invalid path.'; 
        alert(errorString);
        return false;
    }
} // verifyPath


// Verifies a windows workgroup (netbios name)
// netbios names are up to 15 characters of A-Za-z0-9!@#$%^&()-'{}.~

function verifyWorkgroup(wkgp, theName)
{
    var errorString = "";

    if (wkgp == "")
    {
        alert (theName + ': required field.');
        return false;
    }

    if (/^[A-Za-z0-9!@#\$%\^&\(\)\-\'\{\}\.~]+$/.test(wkgp))
    {
        return true;
    }
    else
    {
        errorString = theName + ': invalid workgroup.'; 
        alert(errorString);
        return false;
    }
} // verifyWorkgroup


// verifies that a firmware filename is correct
// currently just ensures that it is not blank
function verifyFirmware(fname, theName)
{
    var errorString = "";

    if (fname == "")
    {
        alert (theName + ': required field.');
        return false;
    }
    return true;
} // verifyFirmware


// verifies a MD5 sum for a firmware update file
// key must be 32 characters long and consist of hex chars only

function verifyMD5Key(key, theName)
{
    var errorString = "";
    var str = String(key);

    if (key == "")
    {
        alert (theName + ': required field.');
        return false;
    }
    if (str.length != 32)
    {
        errorString = theName + ': must be 32 characters.';
        alert (errorString);
        return false;
    }
    if (/^[A-Fa-f0-9]+$/.test(key))
    {
        return true;
    }
    else
    {
        errorString = theName + ': invalid key.\nValid characters are hexidecimal characters.';
        alert(errorString);
        return false;
    }
} // verifyMD5Key


// verifies a config name, the filename extension is optional
// must match the config filename extension in x15.h

function verifyConfigName(cfg, theName)
{
    var errorString = "";

    if (cfg == "")
    {
        alert (theName + ': required field.');
        return false;
    }
    // looks for:
    // 1. one or more [A-Za-z0-9-_] characters
    // 2. An optional file extension
    if (/^[A-Za-z0-9\-\_]+(\-scscfg\.tgz)?$/.test(cfg))
    {
        return true;
    }
    else
    {
        errorString = theName + ': invalid configuration name.\nValid characters are letters, numbers, _ and -.'; 
        alert(errorString);
        return false;
    }
} // verifyConfigName


// verifies a phone number

function verifyPhoneNum(num, theName, required)
{
    var errorString = "";

    // Some fields do not require that a value be entered
    if (num == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // looks for:
    // 1. an optional leading '9' (for dialing out), followed by an optional '-'
    // 2. an optional area code:
    //    a. an optional '1', followed by an optional '-'
    //    b. area code with parentheses, OR
    //    c. area code without parentheses, optionally followed by a '-'
    //    d. 0 cannot be first digit of area code
    // 4. a 3 digit prefix (0 cannot be first digit)
    // 5. an optional '-'
    // 6. a 4 digit suffix
    // if (/^(9\-?)?((1\-?)?(([1-9]\d{2}\-?)|(\([1-9]\d{2}\))))?[1-9]\d{2}\-?[0-9]{4}$/.test(num))
    // look for one or more numbers and '-'
    if (/^[0-9\-]+$/.test(num))
    {
        return true;
    }
    else
    {
        errorString = theName + ': invalid phone number.\n'; 
        alert(errorString);
        return false;
    }
} // verifyPhoneNum


// verifies an email address

function verifyEmail(email, theName)
{
    var errorString = "";

    if (email == "")
    {
        alert (theName + ': required field.');
        return false;
    }

    if (/^((\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,4})+)[\,\;\ ]?)+$/.test(email))
    {
        return true;
    }
    else
    {
        errorString = theName + ': invalid email address.\n'; 
        alert(errorString);
        return false;
    }
} // verifyEmail


// verifies a device port name - alphanumeric and dash allowed

function verifyPortName(port, theName)
{
    if (port == "")
    {
        alert (theName + ': required field.');
        return false;
    }
    // looks for:
    // 1. one or more [A-Za-z0-9-._] characters
    if (/^[A-Za-z0-9\-\.\_]+$/.test(port))
    {
        return true;
    }
    else
    {
        alert(theName + ": invalid name.\nValid characters are '_', '.', '-', letters and numbers."); 
        return false;
    }
} // verifyPortName


// verifies a lantronix tech support case number

function verifyCaseNum(casenum, theName)
{
    if (casenum == "")
    {
        alert (theName + ': required field.');
        return false;
    }
    // looks for:
    // 1. C-<6 digits>-<5 digits>, or
    // 2. <6 digits>-<6 digits>
    if (/^C\-[0-9]{6,6}\-[0-9]{5,5}$/.test(casenum))
    {
        return true;
    }
    else if (/^[0-9]{6,6}\-[0-9]{6,6}$/.test(casenum))
    {
        return true;
    }
    else
    {
        alert(theName + ': invalid case number.');
        return false;
    }
} // verifyCaseNum


// verifies a GSM/GPRS modem bearer service

function verifyBearerSvc(svc, theName)
{
    var svcPattern = /^(AT\+CBST=)((\d{1,3})(,(\d{1,3})(,(\d{1,1}))?)?)?$/;
    var svcArray = svc.match(svcPattern); 

    if (svc == "")
    {
        alert (theName + ': required field.');
        return false;
    }
    if (svcArray == null)
    {
        alert(theName + ': invalid format\n(required format is "AT+CBST=[<speed>[,<name>[,<ce>]]]".');
        return false;
    }

    if (svcArray[1] && svcArray[1] == 'AT+CBST=')
    {
        if (svcArray[3] && svcArray[3] > 128)
        {
            alert(theName + ': invalid speed ' + svcArray[3] + ' (valid values are 0-128).');
            return false;
        }
        if (svcArray[5] && svcArray[5] > 128)
        {
            alert(theName + ': invalid name ' + svcArray[5] + ' (valid values are 0-128).');
            return false;
        }
        if (svcArray[7] && svcArray[7] > 3)
        {
            alert(theName + ': invalid ce ' + svcArray[7] + ' (valid values are 0-3).');
            return false;
        }
        return true;
    }
    else
    {
        alert(theName + ': invalid format\n(required format is "AT+CBST=[<speed>[,<name>[,<ce>]]]".');
        return false;
    }
} // verifyBearerSvc


// Verifies SNMP OID

function verifyOID (val, theName, required)
{
    // Some fields do not require that a value be entered
    if (val == "")
    {
      if (required)
      {
        alert(theName + ': required field.');
        return false;
      }
      else
        return true;
    }
    
    // looks for one or more series of digits followed by a '.', followed by
    // one or more digits
    if (/^(([0-9]+)\.)+([0-9]+)$/.test(val))
    {
        return true;
    }
    else
    {
        alert (theName + ': invalid format (valid characters are 0-9 and ".",\nand must start and end with a digit.');
        return false;
    }
}  // verifyOID


// Verifies a port range, see regular expression below

function verifyRange(range, theName)
{
    // ok for a range to be blank
    if (range == "")
      return true;

    // if (/^[0-9]{1,5} *(- *[0-9]{1,5})?$/.test(range))
    if (/^[0-9]+(:[0-9]+)?(,[0-9]+(:[0-9]+)?)*$/.test(range))
    {
        return true;
    }
    else
    {
        alert(theName + ': invalid port list.\nA port list is a comma-separated list of ports or port ranges (i.e., 3,6:8,10).');
        return false;
    }
}  // verifyRange


-->
